summaryrefslogtreecommitdiffstats
path: root/nuttx/include/nuttx/fs/dirent.h
diff options
context:
space:
mode:
authorpatacongo <patacongo@7fd9a85b-ad96-42d3-883c-3090e2eb8679>2012-08-05 17:44:11 +0000
committerpatacongo <patacongo@7fd9a85b-ad96-42d3-883c-3090e2eb8679>2012-08-05 17:44:11 +0000
commit9fc3bfb88df871e49311aa5e5493e6b2cd519c32 (patch)
tree1cb241b0a84123081c115f5f382fa207ad83cb68 /nuttx/include/nuttx/fs/dirent.h
parentffd511a6a7162f5910bac5746eb4904ebf74b7e7 (diff)
I learned how to spell PSEUDO
git-svn-id: https://nuttx.svn.sourceforge.net/svnroot/nuttx/trunk@5010 7fd9a85b-ad96-42d3-883c-3090e2eb8679
Diffstat (limited to 'nuttx/include/nuttx/fs/dirent.h')
-rw-r--r--nuttx/include/nuttx/fs/dirent.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/nuttx/include/nuttx/fs/dirent.h b/nuttx/include/nuttx/fs/dirent.h
index 8aad4242b8..75867c87ae 100644
--- a/nuttx/include/nuttx/fs/dirent.h
+++ b/nuttx/include/nuttx/fs/dirent.h
@@ -65,12 +65,12 @@
* reference, a position, a dirent structure, and file-system-specific
* information.
*
* For the root psuedo-file system, we need retain only the 'next' inode
* need for the next readdir() operation. We hold a reference on this
* inode so we know that it will persist until closedir is called.
*/
-struct fs_psuedodir_s
+struct fs_pseudodir_s
{
struct inode *fd_next; /* The inode for the next call to readdir() */
};
@@ -140,7 +140,7 @@ struct fs_dirent_s
{
/* This is the node that was opened by opendir. The type of the inode
* determines the way that the readdir() operations are performed. For the
* psuedo root psuedo-file system, it is also used to support rewind.
*
* We hold a reference on this inode so we know that it will persist until
* closedir() is called (although inodes linked to this inode may change).
@@ -166,9 +166,9 @@ struct fs_dirent_s
union
{
- /* Private data used by the built-in psuedo-file system */
+ /* Private data used by the built-in pseudo-file system */
- struct fs_psuedodir_s psuedo;
+ struct fs_pseudodir_s pseudo;
/* Private data used by other file systems */
@@ -65,12 +65,12 @@
* information.
*
- * For the root psuedo-file system, we need retain only the 'next' inode
+ * For the root pseudo-file system, we need retain only the 'next' inode
* need for the next readdir() operation. We hold a reference on this
* inode so we know that it will persist until closedir is called.
@@ -140,7 +140,7 @@ struct fs_dirent_s
/* This is the node that was opened by opendir. The type of the inode
* determines the way that the readdir() operations are performed. For the
- * psuedo root psuedo-file system, it is also used to support rewind.
+ * pseudo root pseudo-file system, it is also used to support rewind.
*
* We hold a reference on this inode so we know that it will persist until